@@ -762,27 +762,27 @@
 'abilon','Abilon (RSS Reader)',
 'aggrevator', 'Aggrevator (RSS Reader)',
 'aiderss', 'AideRSS (RSS Reader)',
-'akregator','<a href="http://akregator.sourceforge.net/" title="Browser home page [new window]" target="_blank">Akregator (RSS Reader)</a>',  
-'applesyndication','<a href="http://www.apple.com/macosx/features/safari/" title="Browser home page [new window]" target="_blank">AppleSyndication (RSS Reader)</a>',
+'akregator','<a href="http://akregator.sourceforge.net/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">Akregator (RSS Reader)</a>',  
+'applesyndication','<a href="http://www.apple.com/macosx/features/safari/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">AppleSyndication (RSS Reader)</a>',
 'betanews_reader','Betanews Reader (RSS Reader)',
-'blogbridge','<a href="http://www.blogbridge.com/" title="Browser home page [new window]" target="_blank">BlogBridge (RSS Reader)</a>',
+'blogbridge','<a href="http://www.blogbridge.com/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">BlogBridge (RSS Reader)</a>',
 'cyndicate','Cyndicate (RSS Reader)',
 'feeddemon', 'FeedDemon (RSS Reader)',
 'feedreader', 'FeedReader (RSS Reader)',
-'feedtools','<a href="http://sporkmonger.com/projects/feedtools/" title="Browser home page [new window]" target="_blank">FeedTools (RSS Reader)</a>',
-'greatnews','<a href="http://www.curiostudio.com/" title="Browser home page [new window]" target="_blank">GreatNews (RSS Reader)</a>',
-'gregarius','<a href="http://devlog.gregarius.net/docs/ua" title="Browser home page [new window]" target="_blank">Gregarius (RSS Reader)</a>',
-'hatena_rss','<a href="http://r.hatena.ne.jp/" title="Browser home page [new window]" target="_blank">Hatena (RSS Reader)</a>',
+'feedtools','<a href="http://sporkmonger.com/projects/feedtools/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">FeedTools (RSS Reader)</a>',
+'greatnews','<a href="http://www.curiostudio.com/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">GreatNews (RSS Reader)</a>',
+'gregarius','<a href="http://devlog.gregarius.net/docs/ua" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">Gregarius (RSS Reader)</a>',
+'hatena_rss','<a href="http://r.hatena.ne.jp/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">Hatena (RSS Reader)</a>',
 'jetbrains_omea', 'Omea (RSS Reader)',
-'liferea','<a href="http://liferea.sourceforge.net/" title="Browser home page [new window]" target="_blank">Liferea (RSS Reader)</a>',
+'liferea','<a href="http://liferea.sourceforge.net/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">Liferea (RSS Reader)</a>',
 'netnewswire', 'NetNewsWire (RSS Reader)',
 'newsfire', 'NewsFire (RSS Reader)',
 'newsgator', 'NewsGator (RSS Reader)',
 'newzcrawler', 'NewzCrawler (RSS Reader)',
 'plagger', 'Plagger (RSS Reader)',
 'pluck', 'Pluck (RSS Reader)',
-'potu','<a href="http://www.potu.com/" title="Potu Rss-Reader home page [new window]" target="_blank">Potu (RSS Reader)</a>',
-'pubsub\-rss\-reader','<a href="http://www.pubsub.com/" title="Browser home page [new window]" target="_blank">PubSub (RSS Reader)</a>',
+'potu','<a href="http://www.potu.com/" title="Potu Rss-Reader home page [new window]" target="_blank" rel="noopener noreferrer">Potu (RSS Reader)</a>',
+'pubsub\-rss\-reader','<a href="http://www.pubsub.com/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">PubSub (RSS Reader)</a>',
 'pulpfiction', 'PulpFiction (RSS Reader)',
 'rssbandit', 'RSS Bandit (RSS Reader)',
 'rssreader', 'RssReader (RSS Reader)',
@@ -794,7 +794,7 @@
 'shrook', 'Shrook (RSS Reader)',
 'straw', 'Straw (RSS Reader)',
 'syndirella', 'Syndirella (RSS Reader)',
-'vienna', '<a href="http://www.vienna-rss.org/" title="Vienna RSS-Reader [new window]" target="_blank">Vienna (RSS Reader)</a>',
+'vienna', '<a href="http://www.vienna-rss.org/" title="Vienna RSS-Reader [new window]" target="_blank" rel="noopener noreferrer">Vienna (RSS Reader)</a>',
 'wizz\srss\snews\sreader','Wizz RSS News Reader (RSS Reader)',
 # PDA/Phonecell browsers
 'alcatel\-be4','Alcatel BE4 (phone)',
@@ -1213,9 +1213,9 @@
 'webtv','WebTV browser',
 'democracy','Democracy',
 # Anonymous Proxy Browsers (can be used as grabbers as well...)
-'cjb\.net','<a href="http://proxy.cjb.net/" title="Browser home page [new window]" target="_blank">CJB.NET Proxy</a>',
-'ossproxy','<a href="http://www.marketscore.com/FAQ.Aspx" title="OSSProxy home page [new window]" target="_blank">OSSProxy</a>',
-'smallproxy','<a href="http://www.smallproxy.ru/" title="SmallProxy home page [new window]" target="_blank">SmallProxy</a>',
+'cjb\.net','<a href="http://proxy.cjb.net/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">CJB.NET Proxy</a>',
+'ossproxy','<a href="http://www.marketscore.com/FAQ.Aspx" title="OSSProxy home page [new window]" target="_blank" rel="noopener noreferrer">OSSProxy</a>',
+'smallproxy','<a href="http://www.smallproxy.ru/" title="SmallProxy home page [new window]" target="_blank" rel="noopener noreferrer">SmallProxy</a>',
 # Other kind of browsers
 'adobeair','AdobeAir',
 'apt','Debian APT',
@@ -1225,7 +1225,7 @@
 'curl','Curl',
 'csscheck','WDG CSS Validator',
 'httrack','HTTrack',
-'fdm','<a href="http://www.freedownloadmanager.org/" title="Browser home page [new window]" target="_blank">FDM Free Download Manager</a>',
+'fdm','<a href="http://www.freedownloadmanager.org/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">FDM Free Download Manager</a>',
 'javaws','Java Web Start',
 'wget','Wget',
 'fget','FGet',
