@@ -100,7 +100,7 @@ sub ShowGraph_graphgooglechartapi() {
 	if ($imagewidth < 1){$imagewidth=640;}
 
 	if ($type eq 'month') {
-		$labellength=3;
+		$labellength=4;
 		print Get_Img_Tag(Graph_Monthly(), $title);
 	}
 	elsif ($type eq 'daysofmonth') {
@@ -484,8 +484,8 @@ sub Chart_Map(){
     my $i = 0;
     for ($i .. (scalar @$blocklabel - 1)) {
 		# fix case of uk
-        if (@$blocklabel[$i] eq 'Great Britain'){ @$blocklabel[$i] =
-'United Kingdom'; }
+        if (@$blocklabel[$i] eq 'Great Britain') { @$blocklabel[$i] = 'United Kingdom'; }
+        if (@$blocklabel[$i] eq 'Russian Federation') { @$blocklabel[$i] = 'Russia'; }
     	print "\tdata.setValue($i, 0, \"".@$blocklabel[$i]."\");\n";
     	print "\tdata.setValue($i, 1, ".@$valdata[$i].");\n";
     	$i++;
